#!/bin/bash

self=${0#./}
base=${self%/*}
curr_dir=`pwd`

#APP_DIR="/var/www/html/outputtime"
APP_DIR="APP_PATH"
NOTIFICATION_APP="$APP_DIR/server_socket.php"
PID_DIR="$APP_DIR/logs"
PID_FILE="$PID_DIR/app.pid"
LOG_DIR="$APP_DIR/logs"
LOG_FILE="$LOG_DIR/app.log"
PHP_EXEC=$(which php)
#PHP_EXEC="/opt/lampp/bin/php"

###############
# REDHAT chkconfig header
# chkconfig: - 58 74
### BEGIN INIT INFO
# Default-Start:	 2 3 4 5
# Default-Stop:	  0 1 6
# Short-Description: start and stop outputtime
# Description: Outputtime notification app.
### END INIT INFO
###############

USAGE="Usage: $0 {start|stop|restart|status}"

pid_file_exists() {
	[ -f "$PID_FILE" ]
}

get_pid() {
	PID=`ps aux | grep php | grep "$APP_DIR" | awk '{print $2}'`
	echo $PID
}

is_running() {
	PID=$(get_pid)
	! [ -z "$PID" ]
}
start_it() {
	#mkdir -p "$PID_DIR"
	#mkdir -p "$LOG_DIR"
	echo "Starting outputtime notification app..."
	#OT_NOTIFICATION_IP="127.0.0.1"
	#OT_NOTIFICATION_PORT="8080"
	#nohup $PHP_EXEC "$NOTIFICATION_APP" "$PHP_EXEC"  1>"$LOG_FILE" 2>&1 &
	$PHP_EXEC "$NOTIFICATION_APP" "$PHP_EXEC"  1>"$LOG_FILE" 2>&1 &

	echo $! > "$PID_FILE"
	echo "Outputtime notification app started with pid $!"
}

stop_process() {
	PID=$(get_pid)
	echo "Killing process $PID"
	kill $PID
}

remove_pid_file() {
	echo "Removing pid file."
	rm -f "$PID_FILE"
}

start_app() {
	if is_running
	then
		PID=$(get_pid)
		echo "Outputtime notification app already running with pid $PID"
		exit 1
	else
		start_it
	fi
}

stop_app() {
	if is_running
	then
		echo "Stopping outputtime notification app..."
		stop_process
		remove_pid_file
		echo "Outputtime notification app stopped."
	else
		exit 1
	fi
}

status_app() {
	if is_running
	then
		PID=$(get_pid)
		echo "Outputtime notification app running with pid $PID"
	else
		echo "Outputtime notification app not running."
	fi
}

case "$1" in
	start)
		start_app
	;;

	stop)
		stop_app
	;;

	restart)
		stop_app
		start_app
	;;

	status)
		status_app
	;;

	*)
		echo $USAGE
		exit 1
	;;
esac

